;Tilemap routine for FF1. Beta version, 9 revisions.
;Designed for use with Silver Edition calculators only.
;Left and right supported along 256 tiles <-->.
;Handlename: Iambian Zenith
;Used TASM for compiling this program. You should do the same, too.
;
;Credits:
;
;Sean McLaughlin for his help with doing bcall(_cpHLDE) without the bcall.
;Patai Gergely and Joe Pemberton for some programming support. (saving registers)
;Patai Gergely, again, for his great ASM tutorial. I would have given up ASM long ago w/o it.
;Shane for his support with loading 2 bytes to register pairs.
;
;
;
;
;I'm being extravagent with the credits, but if you find that your name should be here, then feel free to
;complain. I don't mind resubmitting the same program just becuase it needs a new name...
;(this will give me time to improve upon the current routines :-)
;
;
;
;Testing phases:
;(X) Tilemap displaying
;(X) Movement L/R testing
;(X) Movement (no adding) U/D
;(X) Forward decompression
;(X) Backward decompression
;(X) Real-time decompression
;(X) Movement (with adding) U/D
;(X) Support for external data
;(-) Support for external data in FlashROM (won't happen. Too slow. 'bout 100 extra CCs per byte...)
;(-) Greyscale addon
;(1) 14% done: Completion of the world map: data area
;(X) Sprite addon
;(-) Collision detection (by tile)
;(X) Detailing routine (smooth the rough edges)
;(1) Detailing routine (adds the castles and hotspots...)
;(X) smooth scrolling
;(X) variable speed
;(2) further optimiztions and addons
;(X) External save data file
;
;
#include "ti83plus.inc"
#define findfile(label)  ld hl,label \ rst 20h \ bcall(_ChkFindSym)
#define drawbox(label1)  ld hl,label1 \ call BDD_Lbl01a
;#define rbox(lbl2) ld hl,lbl2 \ call DB_restoredata  ;"restorebox"
#define rbox(label2) call DB_restoredata  ;"restorebox"



;
xpos		equ	appbackupscreen+0     ;x position of character on the map.
ypos		equ	appbackupscreen+1     ;y position of character on the map. Associates with Tbuf and Bbuf.
savebit		equ	appbackupscreen+2     ;bitshifting for left and right.
savebyte	equ	appbackupscreen+3     ;shifting for smoothscrolling up and down.
travelmode	equ	appbackupscreen+4     ;1=walking 2=boat 4=airship
movemode	equ	appbackupscreen+5     ;8=walking 4=boat 2=airship
spriteposition	equ	appbackupscreen+6     ;Used to store sprite position. Is it facing left, right, up, down?
                                              ;0=Down 2=Left 4=Up 6=Right 8=SpriteMask
bitmap1		equ	appbackupscreen+7     ;bitmapbuffer one (for greyscale) LG
spriteshift	equ	appbackupscreen+9     ;To store sprite animation data.
spritetype	equ	appbackupscreen+10    ;The address of the kind of sprite being displayed.
gotcanoe	equ	appbackupscreen+12    ;Do you have the CANOE? This byte set if so.
spriteheight	equ	appbackupscreen+13    ;The height of the sprite off the ground. Used to determine diff between airship and grouns-movement.
templandsprite	equ	appbackupscreen+14    ;the tile that is being replaced by the airship. Used for temp data storage.
airshippos	equ	appbackupscreen+16    ;position on the world map where the airship is being kept.
boatpos		equ	appbackupscreen+18    ;position on the world map where the boat shoud go.
;
; 
;                                     
datawrite	equ	appbackupscreen+250    ;this is where the tilemap routine will write all of its data in
dataget		equ	appbackupscreen+252    ;\ This is the area where the tilemap routine will read its data from.
                                             ;|Replace all references to "ld de,(sec0)" with "ld de,(dataget)" if and
                                             ;|only if it required to make the buffer "externally" supported. (i.e. code
                                             ;/in FlashAPP, data needs to be in RAM...)
datastart	equ	appbackupscreen+254    ;External data support. This is where the data area of the tiles start
dataend		equ	appbackupscreen+256    ;This is where the data area ends
flashrompage	equ	appbackupscreen+258    ;reading from FlashROM. This number will be set to 0 in demo version.
var1		equ	appbackupscreen+260    ;variable for temporary storage.
var2		equ	appbackupscreen+262    ;variable for temporary storage.
var3		equ	appbackupscreen+264    ;variable for temporary storage.
temp		equ	appbackupscreen+266    ;temporary variable.
stackaddress	equ	appbackupscreen+268    ;preserves the stack while the RAM page is being swapped.
intD1		equ	appbackupscreen+270    ;semi-temporary variable for interrupt routine.
intD2		equ	appbackupscreen+272    ;semi-temporary variable for interrupt routine.
intD3		equ	appbackupscreen+274    ;semi-temporary variable for interrupt routine.
iTemp		equ	appbackupscreen+276    ;truly TEMPORARY variable for interrupt routine use.
waterposition	equ	appbackupscreen+278    ;determines water position.
;EQUATES CONTINUE IN "tBoxDat1.asm" from +280 to +305 (single byte)
anothertemp     equ     appbackupscreen+306    ;here so that some things could be sorted out.
sa1counter      equ     appbackupscreen+308    ;counter for looper.
mbtc            equ     appbackupscreen+309    ;remeber cursor position for the MainBox. This is a 2byte space.
detailertable   equ     appbackupscreen+311    ;Pointer to the specific-detailing portion of the detail data.





;spriteheight high=8, low=24, items loaded into register C.
;
;
;
.org userMem-2                                 ;RAM position to where the program should start. -2, to accomodate the next statement.
.db $bb,$6d                                    ;AsmPrgm token. Tells the OS that THIS IS AN ASM PROGRAM, NOT BASIC!
; ret                                           ;So that it cannot be run from the homescreen.
 jr begin                                   ;This is the ION program header. Well... part of it.
.db "Final Fantasy World Demo",0               ;The program title.
begin:
 jp skipbegin
#include "drawtext.asm"  ;needs to be within the RAM limit.
#include "tBoxDat1.asm"  ;Data and code for boxdrawing routine
skipbegin:
 di
 ld hl,appbackupscreen
 ld (hl),$0
 ld de,appbackupscreen+1
 ld bc,100
 ldir
 
 ld a,3
 ld (spriteposition),a

 ld (stackaddress),SP         ;preserves the Stack address.
 ld SP,ArtificialStackEnd
 
 bcall(_clrLCDfull)
 ld hl,$0000
 ld (currow),hl
 ld hl,str0
 bcall(_PutS)
 ld hl,bitmap
 ld (bitmap1),hl

 ld a,8
 ld (spriteheight),a   ;airship sprite height.
 
 ld a,1
 ld (travelmode),a
 ld a,8
 ld (movemode),a
;======================================================= 
installInterruptRoutine: ;used to make water move. Or airship work. If included sprite...




; ld bc,intEnd-intStart
; ld de,intStart
; ld 
 
 
;========================================================
 
 
 ld hl,$0000
 ld (ypos),hl        ;to clean this area before writing. Edit this after implementing so that it reflects "where last was..."

;----------------------------
;Load correct buffer before calling this
;program. One will be provided for testing
;here, but needs to be deleted before 
;application phase is begin.
;----------------------------\
 ld hl,plotsscreen        ; ||
 ld (datawrite),hl        ; ||
 ld hl,$C000              ; ||
 ld (dataget),hl          ; ||
;----------------------------|
;----------------------------/
 
 ld hl,$0000
 ld (currow),hl
 ld hl,str1
 bcall(_PutS)

 xor a
 out (5),a
 findfile(program)
 jp nc,noerror

error:

 ld hl,$0000
 ld (currow),hl
 ld hl,fail
 bcall(_PutS)
 jp quitgame
 
noerror:
 ld a,b
 or a
 jp nz,error  ;the data should NOT be in FlashROM.

 inc de     ;got offset of the data and skipping for...
 inc de     ;increase by two for programs...
 inc de     ;AsmPrgm instruction
 inc de     ;AsmPrgm instruction
 inc de     ;ret instruction, prevents execution from homescreen.
 inc de     ;offset to use program with... just there, but needs to be skipped over...
 
 ld (var1),de
 ld hl,$0000
 ld (currow),hl
 ld hl,str2
 bcall(_PutS) 
 
 ld a,1
 out ($20),a                     ;Sets 15MHz Switch. Now goes fast (15MHz)
 call initializelongbuffer       ;Fills in four RAM pages worth of tilemap data.
 xor a
 out ($20),a                     ;Reset 15MHz Switch. Now goes regular speed (6MHz)
 ld hl,ASST
 ld (spritetype),hl
 ld hl,$0204
 ld (travelmode),hl
 
 
 ld a,4
 ld (savebyte),a
 ld (savebit),a                 ;4 pixels offset, so that there is a whole tile exactly in the middle.
 ld (gotcanoe),a                ;so we set it because in our demo, it's a got!

;Change Boat position when doing real game:
 findfile(savefile)
 jr nc,detectLoadSaveFile

 ld hl,(xpos)
 push hl
  ld hl,$93d3
  ld (boatpos),hl
  ld (xpos),hl
  call CoordToMapPos
  ld (hl),$18
 pop hl
 ld (xpos),hl
 call CoordToMapPos

; 
;
 
 
detectLoadSaveFile:
 in a,(5)
 push af
  xor a
  out (5),a
  findfile(savefile)  ;my own little equate. Don't know what it means? Look above at the define directive under our include file.
  jp nc,skipReset         ;savefile not found, skipping over to the main routine w/ prdmnd data.
 pop af
 out (5),a
 jp programstart

skipReset:
 pop af
 ld a,b
 or a
 bcallnz(_Arc_Unarc)
 findfile(savefile)
 inc de
 inc de
 ex de,hl
 ld de,appbackupscreen
 ld bc,25
 ldir
 ld hl,(xpos)
 push hl
  ld hl,(airshippos)
  ld (xpos),hl
  call CoordToMapPos
  call increaseincreasefix
  ld (hl),$15  ;our airship sprite.
  ld hl,(boatpos)
  ld (xpos),hl
  call CoordToMapPos
  call increaseincreasefix
  ld (hl),$18  ;our boat goes here. {Insert sprite for it soon...}
 pop hl
 ld (xpos),hl

 call CoordToMapPos
 
 ld (dataget),hl
 
 ld hl,plotSScreen
 ld (datawrite),hl
 ld hl,(airshippos)
 
; 
;When character status is added in, make code for this area, too! 
; 
 
;Syptomatic issues: The game does not recognize movement of the added routine.
; Boat not fixed yet. Try to add a common sprite refresh routine for the repositioning of all sprites
;to make paging a bit easier when landing or taking off or going into port (or into sea).
;Side note: If game does not work, erase AppVar, which may be incompatible with the last program.
 
programstart:
 ld hl,(dataget)
 call increaseincreasefix
 ld a,$ff
 out (1),a
 ld a,%10111110  ;activates grops FE and BF.
 out (1),a
 in a,(1)
 rra
 jp nc,movedown2
 rra
 jp nc,moveleft2
 rra
 jp nc,moveright2
 rra
 jp nc,moveup2
 rra
 push af
  call restorerestorefix
 pop af
 jp nc,displayworldmap
 rra
 call nc,beginlanding   ;highly experimental at this time.
 rra
 call nc,statusScreen
 rra
 jp nc,quitgame
 ld a,$ff
 out (1),a
 ld a,$fd
 out (1),a
 in a,(1)
 cp $fe
 jp z,nextMode
 cp $fd
 call z,dispnumbers
 cp $fb
 jp z,changeExecutionSpeed
 call tilemove
 jr programstart
 
statusScreen: ;the menu.
;DEL /MODE/2ND /Y=  /UP  /RGHT/LEFT/DOWN
;$7F /$BF /$DF /$ED /$F7 /$FB /$FD /$FE
 call DrawMainMenu
 ld hl,BDD_mainBox
 call BDD_InitializePointers
 ld hl,BDD_mainBox+4
 xor a
 ld (mbtc),a
 call DrawFormattedText
mainMenuLooper:
 call fastCopy
 call directGetKey
 cp $BF
 jr z,quitStatusMenuBegin
 ld hl,mbtc
 ld de,$05FF
 push hl
 call keypressDChange
 ld a,(hl)
 push af
 ld hl,BDD_mainBox
 call BDD_InitializePointers
 ld hl,BDD_mainBox+4
 pop af
 push af
 call DrawFormattedText
 pop af
 pop hl
 ld de,mainJumpTable
;insert test, add, and the jump table.
 
; cp $DF
; call z,universalBoxJump
 jr mainMenuLooper
quitStatusMenuBegin:
 call rMainMenu
 call ModeOff
 ret
 
ModeOff:
 ld a,$FF
 out (1),a
 ld a,%10111110
 out (1),a
 nop \ nop
 in a,(1)
 cp $BF
 jr z,ModeOff
 ret 
 
 
 
 
 
 
 
 
;cont'd
 
 
 
 
universalBoxJump:  ;de=JumpTableEntryPoint, hl=AddressOfBoxTestCounter
 ld a,(hl)
 add a,a
 add a,(hl)  ;x3 for each jp instruction
 ld l,a
 ld h,0
 add hl,de
 jp (hl)           ;all return statements end and return to point of call, from the previous box routine!

mainJumpTable:
; jp jumpItemMenu
; jp jumpStatusMenu
; jp jumpMagicMenu
; jp jumpWeaponMenu
; jp jumpArmorMenu
 
 
 
 
 
 
  
 
 
 
 
keypressDChange:  ;hl=address of cursor key. (hl)=U/D position, (hl+1)=L/R position. D=upperlimit UP, E=lowerlimit DOWN, B=leftlimit C=rightlimit
 push af
 push hl
 call keypressDChangeSub
 pop hl
 pop af
 ret

keypressDChangeSub:
 cp $FE
 jr nz,dgk_skU
 inc (hl)
 ld a,d
 cp (hl)
 ret nz
 ld (hl),e
 inc (hl)  ;to make up for inc e \ ld (hl),e \ dec e
 ret
dgk_skU:
 cp $F7
 jr nz,dgk_skD
 dec (hl)
 ld a,e
 cp (hl)
 ret nz
 ld (hl),d
 dec (hl)  ;to make up for dec d \ ld (hl),d \ inc d
 ret
dgk_skD:
 inc hl   ;for next byte
 cp $FB
 jr nz,dgk_skL  ;left=0, right=max
 dec (hl)
 ld a,b
 cp (hl)
 ret nz
 ld (hl),c
 dec (hl)
 ret
dgk_skL:
 cp $FD
 ret nz
 inc (hl)
 ld a,c
 cp (hl)
 ret nz
 ld (hl),b
 inc (hl)
 ret

 
 
beginlanding:
 pop hl
 ld hl,programstart
 push hl
 ld bc,(spritetype)
 ld hl,ASST
 or a
 sbc hl,bc
 jr z,landourairship   ;landing the airship
 ld hl,(dataget)
 call increaseincreasefix
 ld a,(hl)
 cp $15                 ;whatever the airship sprite was saved in here...
			;When the airship is uncovered in the Rhyukhan (think it's spelled this way?) Desert
			;a small routine will put the tile data in the spot and get the tile will be put
			;into a temporary spot.
 jr nz,triedtotakeoff   ;kill the subrotine if there is no airship to board.
 ld a,(templandsprite)
 ld (hl),a
 push af
  call restorerestorefix
 pop af
 ld hl,ASST
 ld (spritetype),hl
 call animatetakeoff
;travelmode	equ	appbackupscreen+4     ;1=walking 2=boat 4=airship
;movemode	equ	appbackupscreen+5     ;8=walking 4=boat 2=airship
 ld a,4
 ld (travelmode),a
 rrca
 ld (movemode),a
 ld hl,$FFFF
 ld (airshippos),hl
 ret
triedtotakeoff:
 call restorerestorefix
 ret

landourairship:
 ld hl,(spritetype)
 ld bc,ASST
 or a
 sbc hl,bc
 ret nz        ;if you tried to fly an airship from the boat... heh. But there has to be error protection.
 call animatelanding
 ld hl,(dataget)
 call increaseincreasefix
 ld a,(hl)
 ld (templandsprite),a
 cp 01
 jr z,landitnow
 cp 03
 jr z,landitnow
 call restorerestorefix
 call animatetakeoff
 ld hl,$FFFF
 ld (airshippos),hl
 ret

landitnow:
 ld (hl),$15
 call restorerestorefix
 ld hl,(xpos)
 ld (airshippos),hl
 ld hl,C1ST
 ld (spritetype),hl
 ld a,1
 ld (travelmode),a
 ld a,8
 ld (movemode),a
 ret






 
 
 
 
 
 
 
animatetakeoff:
 ld c,-1
 jr animateairshipmovement
animatelanding:
 ld c,1
; jr animateairshipmovement

animateairshipmovement:
;spriteheight high=8, low=24, items loaded into register C.
 ld b,16
animateairshipmovementloop:
 push bc
  ld a,(spriteheight)
  add a,c            ;either -1 or 1, determined above.
  ld (spriteheight),a
  call tilemove
 pop bc
 djnz animateairshipmovementloop
 ret


increaseincreasefix:
 call increaseH
 call increaseH
 call increaseH
 call increaseH
 call increaseHL
 call increaseHL
 call increaseHL
 call increaseHL
 call increaseHL
 call increaseHL
 ret
restorerestorefix:
 call decreaseH
 call decreaseH
 call decreaseH
 call decreaseH
 call decreaseHL
 call decreaseHL
 call decreaseHL
 call decreaseHL
 call decreaseHL
 call decreaseHL
 ret
 
 
 
movedown2:
 push af
  call increaseH
  push hl
   call testvehicles
  pop hl
  push af
   call decreaseH
   call restorerestorefix
  pop af
 pop hl
 ld a,h
 jp nz,movedown
 jp programstart
 
moveleft2:
 push af
  call decreaseHL
  push hl
   call testvehicles
  pop hl
  push af
   call increaseHL
   call restorerestorefix
  pop af
 pop hl
 ld a,h
 jp nz,moveleft
 jp programstart
 
moveright2:
 push af
  call increaseHL
  push hl
   call testvehicles
  pop hl
  push af
   call decreaseHL
   call restorerestorefix
  pop af
 pop hl
 ld a,h
 jp nz,moveright
 jp programstart
 
moveup2:
 push af
  call decreaseH
  push hl
   call testvehicles
  pop hl
  push af
   call increaseH
   call restorerestorefix
  pop af
 pop hl
 ld a,h
 jp nz,moveup
 jp programstart
 
testvehicles:  ;8=walking 4=boat 2=airship
 push hl
  or a
  ld hl,ASST
  ld bc,(spritetype)
  sbc hl,bc
  jp z,testMoveAirship
  or a
  ld hl,CNST
  sbc hl,bc
  jp z,testMoveCanoe
  or a
  ld hl,BTST
  sbc hl,bc
  jp z,testMoveBoat
 pop hl

;
;Have the program test for the position and change to boat or airship or canoe AFTER tilemap routine
;Must be tested during the programstart phase.
;
testMoveCharacter:  ;don't move if ZERO flag is set.
 
 ld a,(hl)
 or a
 ret z
 cp 05
 ret z
 cp 04
 jr z,testForCanoeMove
 cp $18
 jp z,testForBoatMove
 cp $15
 jr z,endTestMoveCharacter
 cp $25 ;tile walk-through boundry.
 jp nc,negateZero  ;if hit, then walkthough, since =0; but no walkthough if =!0 and greater than.
 cp 00
 ret z
endTestMoveCharacter:
 jr testMoveCanoeMove ;same story @ testMoveAirship

testForCanoeMove:
; pop hl
 ld a,(gotcanoe)
 or a
 ret z
 ld hl,CNST
 ld (spritetype),hl
 jr testMoveCanoeMove ;same story @ testMoveAirship

testMoveCanoe:
 pop hl
; ld hl,negateZERO  ;to return to this statement.
; push hl
 ld a,(hl)
 or a
 ret z
 cp $18
 jp z,testForBoatMove
 cp 5
 ret z
 cp 4
 jp z,testMoveCanoeMove
 ld hl,C1ST
 ld (spritetype),hl
testMoveCanoeMove:
 ld a,1
 or a
 ret

testMoveAirship:
 pop hl
 jr testMoveCanoeMove  ;the ending section of the one above matched this one. No use in repeating it... " ld a,1 \ or a \ ret "

testForBoatMove:

 ld (hl),$00

 ld hl,BTST
 ld (spritetype),hl
; ld hl,(boatpos)
; ld de,(xpos)
; ld (xpos),hl
; call CoordToMapPos
; ld (hl),$00
; ld (xpos),de
; call CoordToMapPos 
 ld hl,$FFFF
 ld (boatpos),hl
 
;travelmode	equ	appbackupscreen+4     ;1=walking 2=boat 4=airship
;movemode	equ	appbackupscreen+5     ;8=walking 4=boat 2=airship
 ld a,2
 ld (travelmode),a
 rlca
 ld (movemode),a
 or a
 ret
 
testGitOfftoCanoe:
 call testForCanoeMove
 ld a,1
 ld (travelmode),a
 ld a,8
 ld (movemode),a
 jr continueboatMove
 
testMoveBoat:
 pop hl
 ld a,(hl)
 or a
 jp z,negateZERO
 cp 04
 jp z,testGitOfftoCanoe
 cp 06
 jp nz,negateZERO
 ld hl,C1ST
 ld (spritetype),hl
 ld hl,$0801
 ld (travelmode),hl  ;saves across travelmode and movemode
continueboatMove: 
 in a,(5)
 push af
  push hl
  ld hl,(xpos)
  ld (boatpos),hl
  call CoordToMapPos
  call increaseincreasefix
  ld (hl),$18
  pop hl
 pop af
 out (5),a
 
 
 ld a,1
 or a
 ret


negateZERO:  ;XOR the ZERO flag
 or a
 jr nz,negateZEROset
 xor a
 cp 1
 ret
negateZEROset:
 xor a
 ret


  
quitgame:
 xor a
 out (5),a                   ;restore proper RAM page upon quitting. If not done, then the calc will crash.
 ld SP,(stackaddress)
generatesavefile:
 findfile(savefile)
 ld hl,27                  ;our new appvar will be 25 bytes in length.
 bcallc(_CreateAppVar)
 findfile(savefile)
 ld a,b
 or a
 bcallnz(_Arc_Unarc)
 findfile(savefile)
 inc de
 inc de
 ld hl,appbackupscreen
 ld bc,25
 ldir
 ei
 ret
 

nextMode:
;travelmode	equ	appbackupscreen+24     ;1=walking 2=boat 4=airship
;movemode	equ	appbackupscreen+25     ;8=walking 4=boat 2=airship
 res fracDrawLFont,(IY+fontFlags)
 ld a,$00
 ld (penrow),a
 ld (pencol),a
 ld a,(travelmode)
 cp 1
 jr z,walkmode
 cp 2
 jr z,boatmode
 ld hl,tm1
 bcall(_VPutS)
 ld a,1
 ld b,8
 jr nextmodeEnd
walkmode:
 ld hl,tm2
 bcall(_VPutS)
 ld a,2
 ld b,4
 jr nextmodeEnd
boatmode:
 ld hl,tm3
 bcall(_VPutS)
 ld a,4
 ld b,2
nextmodeEnd:
 ld (travelmode),a
 ld a,b
 ld (movemode),a
; call fastCopy
 bcall(_getKey)
 jp programstart

  
dispnumbers:
 ld a,(xpos)
 ld l,a
 ld h,$0
 ld de,ASCIIcounter1
 call convertHLtoASCII
 ld a,(ypos)
 ld l,a
 ld h,$0
 ld de,ASCIIcounter2
 call convertHLtoASCII
 xor a
 ld (penRow),a
 set textWrite,(IY+sGrFlags)
 ld a,40
 ld (penCol),a
 ld hl,ASCIIcounter1
 bcall(_VPutS)
 res textWrite,(IY+sGrFlags) 
 ret
 
displayworldmap:
 in a,(5)
 push af
  ld IX,plotsscreen+2
  ld hl,$C000
  ld a,2
  out (5),a
  ld b,64
drawloopsubone:
  push bc
   ld b,8
drawloopsubtwo:

   push bc
    call fillbytesubroutine
   pop bc
   djnz drawloopsubtwo
  pop bc

  call fastcopy
  inc IX
  inc IX
  inc IX
  inc IX
  call increaseH
  call increaseH
  call increaseH
  djnz drawloopsubone
  call fastcopy      ;must include sometime...
 pop af
 out (5),a
 ld a,(ypos)
 add a,4
 rrca
 rrca
 and %00111111
 ld L,a
 ld a,(xpos)
 add a,6
 rrca
 rrca
 and %00111111
 add a,16
 ld H,0
 add hl,hl
 add hl,hl
 ld d,h
 ld e,l
 add hl,hl
 add hl,de
 ld de,plotsscreen
 add hl,de
 ld e,a
 xor a
 ld d,a
 srl e
 rra
 srl e
 rra
 srl e
 rra
 rlca
 rlca
 rlca
 add hl,de
 ld b,a
 ld d,%01111111
 ld e,%10000000
 or a
 jr z,WMDISP_NoShiftloop
WMDISP_Shiftloop:
 rrc d
 rrc e
 djnz WMDISP_Shiftloop
WMDISP_NoShiftloop:
 ld a,(hl)
 and d
 ld (hl),a
 call fastcopy
 call megadelay
 ld a,(hl)
 or e
 ld (hl),a
 call fastcopy
 call megadelay
 jr WMDISP_NoShiftLoop
 
megadelay:
 push bc
  ld b,$80
megadelaysub:
  push bc
   ld bc,$FFFF
megadelaysubloop:
   ld a,$ff
   out (1),a
   ld a,$fe
   out (1),a
   nop \ nop
   in a,(1)
   cp $FF
   jr nz,quitmegadelay
   dec bc
   ld a,b
   cp c
   jr nz,megadelaysubloop
  pop bc
  djnz megadelaysub
 pop bc
 ret
  
quitmegadelay:
  pop bc       ;restores BC
 pop bc        ;restores BC
 pop hl        ;Fixes stack to return to programstart.
 jp programstart
 
fillbytesubroutine: ;designed to fill the byte before pasting. Takes 8 iterations, and load address according to IX. Address to read =HL
 ld c,$0
 ld b,8
FBSR_subloop:
 ld a,1
 cp (hl)
 rl c
 call increaseHL
 call increaseHL
 call increaseHL
 call increaseHL
 djnz FBSR_subloop
 ld (IX+0),c
 inc IX
 ret


convertHLtoASCII:          ;DE=address to store string. HL=number
Num2Dec	ld	bc,-10000
	call	Num1
	ld	bc,-1000
	call	Num1
	ld	bc,-100
	call	Num1
	ld	c,-10
	call	Num1
	ld	c,-1

Num1	ld	a,'0'-1
Num2	inc	a
	add	hl,bc
	jr	c,Num2
	sbc	hl,bc

	ld	(de),a
	inc	de
	ret

changeExecutionSpeed:
 in a,($20)
 or a
 ld a,1
 jp z,CES_NoFix
 xor a
CES_NoFix:
 out ($20),a
 jp programstart
 
 
 
movedown:
 xor a
 ld (spriteposition),a

 ld a,(movemode)
 ld b,a
MVD_Loop:
 push bc
 ld hl,(dataget)
 ld a,(travelmode)
 ld b,a
 ld a,(savebyte)
MVD_Subloop:
 inc a
 djnz MVD_Subloop
 cp 8
 jp nz,MVD_NoFix   ;less than, jump. No jump if equal to or greater than...
 xor a

 push hl
 push af
 ld hl,ypos
 inc (hl)
 ld hl,(dataget)
 call increaseH
 ld (dataget),hl
 pop af
 pop hl
 
MVD_NoFix:
 ld (savebyte),a
 call tilemove
 pop bc
 djnz MVD_Loop

 jp programstart

moveup:
 ld a,4
 ld (spriteposition),a
 ld a,(movemode)
 ld b,a
MVU_Loop:
 push bc
 ld hl,(dataget)
 ld a,(travelmode)
 ld b,a
 ld a,(savebyte)
 or a
 jp nz,MVU_NoFix

 push hl
 push af
 ld hl,ypos
 dec (hl)
 ld hl,(dataget)
 call decreaseH
 ld (dataget),hl
 pop af
 pop hl

 ld a,$8
MVU_NoFix:
MVU_SubLoop: 
 dec a
 djnz MVU_SubLoop
 ld (savebyte),a
 call tilemove
 pop bc
 djnz MVU_Loop

 jp programstart

 
moveleft:
 ld a,2
 ld (spriteposition),a
 ld a,(movemode)
 ld b,a
MVL_Loop:
 push bc
 ld a,(travelmode)
 ld b,a
 ld a,(savebit)
 or a
 jp nz,MVL_NoFix
 
 push hl
 push af

 ld hl,xpos
 dec (hl)
 ld hl,(dataget)
 xor a
 cp L      ;seeing if L and E are the same. If Z set, we reached end of world.
 dec hl    ;altering register pairs does not alter the flags.
 jr nz,skipnum
 inc h
skipnum:           ;part of routine shared by both right and left-going sides. Size optimization.
 ld (dataget),hl

 pop af
 pop hl

 ld a,$8
MVL_NoFix:
 dec a
 djnz MVL_NoFix
 ld (savebit),a
 ld hl,(dataget)
 call tilemove
 pop bc
 djnz MVL_Loop
 jp programstart

moveright:
 ld a,6
 ld (spriteposition),a
 ld a,(movemode)
 ld b,a
MVR_Loop:
 push bc
 ld a,(travelmode)
 ld b,a
 ld a,(savebit)
MVR_Subloop:
 inc a
 djnz MVR_Subloop
 cp 8
 jp nz,MVR_NoFix   ;less than, jump. No jump if equal to or greater than...
 xor a
 push hl
 push af
 ld hl,xpos
 inc (hl)
 ld hl,(dataget)
 inc hl
 xor a
 cp L
 jr nz,skipnum2
 dec h
skipnum2:
 ld (dataget),hl

 pop af
 pop hl

MVR_NoFix:
 ld (savebit),a
 ld hl,(dataget)
 call tilemove
 pop bc
 djnz MVR_Loop

 jp programstart

 

;====================================================================================================
; The newest revision of the tilemap. It's design had a complete overhaul since the last time
;the design was implemented. This time, it features smoothscrolling in a slightly different way.
;The interrupts MUST remain disabled (for Mode 1 or Mode 2 that makes romcalls)
;for the duration of this subroutine, because index register IY is being altered. The OS won't
;like it, and it may cause a crash. Because of that, the IY register is also pushed onto the stack.
;Since I've adopted Dwedit's style of coding (since the first time I saw it was when he used it),
;there should not be any problems with the stack.
;====================================================================================================
.db "Text Pointer" ;here so that easy ID on CalcSys.

tilemove:
 ld hl,bitmap
 ld (bitmap1),hl
 call tilemove2
 ret
 
 di
 ld a,$80
 out ($10),a
 ld hl,tilemovesecondender
 push hl
 push IY
; ld hl,gbitmap
 ld hl,bitmap
 ld (bitmap1),hl
 ld hl,spriteshift
 dec (hl)
 call displayingCharacterSprite
 jp TMSWS_SkipShifting  ;after the step function's sorted out.
tilemovesecondender:
 ret

tilemove2:
 di
 push iy                ;unlike any other program, we're going to use the IY register, too.
  ld bc,(sa1counter)
tilemove3: ;delay routine to handle greyscale
  dec bc
  nop \ nop \ nop
  ld a,b
  cp c
  jr nz,tilemove3
 
  ld a,$80
  out ($10),a

  call displayingCharacterSprite
    
  ld a,(spriteshift)
  bit 3,a
  jr z,TMSWS_SkipShifting
  and %00000111
  jr nz,TMSWS_SkipShifting

  ld b,8
  ld hl,waterposition
  inc (hl)
  ld a,(hl)
  and %00000011
  cp 3
  jr nz,MWM_SkipResult
  inc (hl)  
MWM_SkipResult:
  ld a,(hl)
  and %00000011
  ld hl,(bitmap1)  ;should end up with tile already ($00 = seawater, same as start of bitmap)
  or a
  jr z,MWM_NoBitLoop

  
MWM_BitLoop:
  rrc (hl)
  inc hl
  djnz MWM_BitLoop
  jr MWM_EndAll

MWM_NoBitLoop:
  rlc (hl)
  inc hl
  djnz MWM_NoBitLoop
MWM_EndAll:

  ld hl,(bitmap1)
  ld de,32        ;for the lakewater
  add hl,de
  ld b,8
TMSWS_InternalShiftLoop2:
  rrc (hl)
  inc hl
  djnz TMSWS_InternalShiftLoop2

TMSWS_SkipShifting:
  ld de,plotsscreen
  ld a,(savebit)
  neg
  add a,8               ;8=0, 7=1, 6=2, 5=3, 4=4, 3=5...
  ld l,a
  ld h,$0
  ld bc,addloopstart       ;start of the addition loop, designed to replace the need to shift.
  add hl,bc
  ld (loadnewaddress+1),hl ;saves this for immediate reference.
  ld (temp),hl
  ld c,$20                 ;set column number for LCD driver. ld a,c then out (10h),a
  ld b,12                  ;12 columns on the screen
  ld hl,(dataget)
  ld a,(savebyte)
  or a
  jr nz,colmove
;  dec h
  xor a
  ld (savebyte),a
  
colmove:

  ld a,c
  out ($10),a
  push bc
  
rowmove:
   push de
    in a,(5)
    push af
     push hl
      ld a,(savebyte)
      or a
      jp z,RM_NoInitialize
      call firstIteration
      ld a,7
      jp rowmoveloop
     
RM_NoInitialize:
     
      ld a,8
rowmoveloop:
      ex af,af'
       push hl
        ld a,(hl)
        inc hl
        ld l,(hl)
        ld h,$0
        ld bc,(bitmap1)
        add hl,hl
        add hl,hl
        add hl,hl
        add hl,bc
        push hl
        pop iy
        ld l,a
        ld h,$0
        add hl,hl
        add hl,hl
        add hl,hl
        add hl,bc
        push hl
        pop ix
        call drawtile
       pop hl
       call increaseH
      ex af,af'
      dec a
      jp nz,rowmoveloop
      ld a,(savebyte)
      or a
      call nz,lastIteration
     pop hl
    pop af
    out (5),a
    inc hl
    xor a
    cp L
    jr nz,TM_noFix
    call decreaseH
TM_noFix:
   pop de
   inc de
  pop bc
  inc c
  djnz colmove
 pop iy
  
 ret
 

drawtile:    ;DE is where to write the data. IX and IY holds pointers to the bitmap.
 ld b,8      ;jump to drawtileloop with a value in B in it already for a limited write.
drawtileloop:
 ld a,(de)
 out ($11),a    ;writing old byte to the screen
 ld hl,(temp)
 push hl
 ld h,(ix+0)    ;19
 ld l,(iy+0)    ;19
 ret           ;to jump to the shifting.
loadnewaddress:
 jp 0000       ;will be self-modifying.
addloopstart:
 add hl,hl     ;fastest bitshifting we have...
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
addloopend:
 inc ix        ;10
 inc iy        ;10
 ld a,h        ;4
 ld (de),a     ;7
 ld hl,12      ;10
 add hl,de     ;11
 ex de,hl       ;hl is trash. DE is what is needed.
 djnz drawtileloop ;14

 ret

firstIteration:
 push hl
  ld a,(hl)
  inc hl
  ld l,(hl)
  ld h,$0
  ld bc,(bitmap1)
  add hl,hl
  add hl,hl
  add hl,hl
  add hl,bc
  push hl
  pop iy
  ld l,a
  ld h,$0
  add hl,hl
  add hl,hl
  add hl,hl
  add hl,bc
  push hl
  pop ix
  ld a,(savebyte)
  or a
  jp nz,FITM_NoFix
  ld a,8
FITM_NoFix:
  ld c,a
  ld b,$0
  add ix,bc
  add iy,bc
  ld a,(savebyte)
  neg
  add a,8
  or a
  jp nz,FITM2_NoFix
  ld a,8
FITM2_NoFix:
  ld b,a
  call drawtileloop
 pop hl
 call increaseH
 ret

lastIteration:
 push hl
  ld a,(hl)
  inc hl
  ld l,(hl)
  ld h,$0
  ld bc,(bitmap1)
  add hl,hl
  add hl,hl
  add hl,hl
  add hl,bc
  push hl
  pop iy
  ld l,a
  ld h,$0
  add hl,hl
  add hl,hl
  add hl,hl
  add hl,bc
  push hl
  pop ix
  ld a,(savebyte)
  or a
  jp nz,LITM_NoFix
  ld a,8
LITM_NoFix:
  ld b,a

  call drawtileloop
 pop hl
 ret



;====================================================================================================
;
;
;
;
;====================================================================================================
 


fastCopy:
	di
	exx
	ld	a,$80				; 7
	out	($10),a				; 11
	ld	hl,plotsscreen-12-(-(12*64)+1)	; 10
	ld	a,$20				; 7
	ld	c,a				; 4
	inc	hl				; 6 waste
	dec	hl				; 6 waste
fastCopyAgain:
	ld	b,64				; 7
	inc	c				; 4
	ld	de,-(12*64)+1			; 10
	out	($10),a				; 11
	add	hl,de				; 11
	ld	de,10				; 10
fastCopyLoop:
	add	hl,de				; 11
	inc	hl				; 6 waste
	inc	hl				; 6 waste
	inc	de				; 6
	ld	a,(hl)				; 7
	out	($11),a				; 11
	dec	de				; 6
	djnz	fastCopyLoop			; 13/8
	ld	a,c				; 4
	cp	$2B+1				; 7
	jr	nz,fastCopyAgain		; 10/1
	exx
	ei
	ret

initializelongbuffer:

 di                     ;messing with a shadow register. Interrupts must be disabled.

 ld a,2                 ;extra RAM page.
 ex af,af'
 ld hl,(var1)
 ld (temp),hl
 ld b,4
 
initFirstLoop:
 push bc
  ld de,$C000            ;each RAM page is $4000 (or 16384) bytes long.
  ld b,32

initSecondLoop:
  push bc
   push de
    ld hl,(temp)
    ld de,plotsscreen
    call fdecompress
    call fdecompress
    ld (detailertable),hl
    ld (temp),hl
   pop de
   ld hl,plotsscreen
   ld bc,512
   ex af,af'
    out (5),a
   ex af,af'
   ldir
  pop bc
  djnz initSecondLoop
  ex af,af'
  inc a
  ex af,af'
 pop bc
 djnz initFirstLoop
 ld a,$2
 out (5),a
 
 
 
 ld b,00       ;256 loops --- water detailing routines.
 ld hl,$C000
secoFirstLoop:
 push bc
  call AD
 pop bc
 djnz secoFirstLoop

 
  
 ld IX,(detailertable)  ;==start reading from the uncompressed tilemap detailing data from this address.
 ld de,$C000
 xor a
 out (5),a
 
 
spotdetailingloop:
 in a,(5)
 push af
  ld H,(ix+0)
  ld a,H
  or a
  jp z,quitspotdetailingloop
  ld L,(ix+1)
  ld C,(ix+2)
  inc ix
  inc ix
  inc ix
  xor a
  sla h
  rla
  sla h
  rla
  srl h
  srl h
  add a,2    ;offset for the RAM pages in use.
  out (5),a
  add hl,de
  ld (hl),c
 pop af
 out (5),a
 jr spotdetailingloop
quitspotdetailingloop:
 pop af
 out (5),a
 
 ld a,2
 out (5),a
 
 ei
 ret                    ;End call to the decompression initialization. 
 
 
 
;======================================================================================================
;******************************************************************************************************
;-------------------- Forward moving decompression routine (tested. Works okay.) ----------------------
;******************************************************************************************************
;======================================================================================================
;ARG: HL=source
;     DE=destination
;Notes: B is the subloop counter. C is the total loop counter.
;       Carry is set when addition sends result over edge. See below.
;
fdecompress:

 xor a
 out (5),a
 ld c,a       ;For the counter, register C needs to be reset.
 ld a,(hl)
 or a
 jr z,FSpecialTile  ;identifies as all water. No further looping is necessary
 
 
FDecompressLoop:

 ld a,(hl)    ;above was taken out of the loop to make it faster. This is required to run the loop.

 push bc      ;since register C is being destroyed in this subloop...

  ld b,a       ;the number just viewed was the loop counter.
  ld c,b       ;hold the value of register B for a while (to be added to total count)
  inc hl       ;shunt register HL upward to view the number being copied.
  ld a,(hl)    ;gotta know what that number is...
  sub $f6      ;to get the offset correct (from high number lowest starting at 0)
  inc hl       ;get to the next number for next iteration.

FLoopAround:
  ld (de),a
  inc de
  djnz FLoopAround
  ld a,c       ;Restores value back to register A that was in B before the djnz loop from directly above.

 pop bc       ;restore register C.

 add a,c      ;adds current counter by current result. Carry set if too much (meaning, stop loop!!!)
 ld c,a       ;send back result to register C. Does not alter the flags (meaning carry is not affected)

 jr nc,FDecompressLoop
 ret          ;to end the call to decompressloop.

FSpecialTile:
 inc hl       ;|_To set next number second time this loop is run (so no external data is needed!)
 inc hl       ;|/
 xor a        ;number that corresponds to seawater.
 ld b,0       ;to make djnz loop run 256 times.

FLoopAround2:

 ld (de),a
 inc de
 djnz FLoopAround2
 ret          ;to end the call to decompressloop.

increaseH:
 inc h
 xor a
 cp h
 ret nz
 ld h,$C0     ;beginning of RAM page.
 in a,(5)
 inc a
 cp 6
 jr nz,incHnoFix
 ld a,2
incHnoFix:
 out (5),a
 ret
 
increaseHL:
 inc hl
 xor a
 cp h
 ret nz
 ld h,$C0     ;beginning of RAM page.
 in a,(5)
 inc a
 cp 6
 jr nz,incHnoFix2
 ld a,2
incHnoFix2:
 out (5),a
 ret
 

decreaseH:
 dec h
 ld a,$BF
 cp h
 ret nz
 ld h,$FF
 in a,(5)
 dec a
 cp 1
 jr nz,decHnoFix
 ld a,5
decHnoFix:
 out (5),a
 ret
 
decreaseHL:
 dec hl
 ld a,$BF
 cp h
 ret nz
 ld h,$FF
 in a,(5)
 dec a
 cp 1
 jr nz,decHnoFix2
 ld a,5
decHnoFix2:
 out (5),a
 ret

;============================================================================
CenterSpriteRoutine:
;ARG: C  = Yposition
;     DE = Address of the bitmask
;     IX = Address of the sprite
;Notes: All registers are destroyed. This routine assumes
;       center position on the screen.
;============================================================================
 ld L,c
 ld h,$0
 add hl,hl
 add hl,hl
 ld c,L
 ld b,h
 add hl,hl
 add hl,bc
 ld bc,plotsscreen+5
 add hl,bc
 ld b,16 \ ld c,10
drawLoop:
 ex de,hl
 ld a,(de)
 and (hl)
 or (IX+0)
 ex de,hl
 ld (hl),a
 inc hl
 inc de
 ex de,hl
 ld a,(de)
 and (hl)
 or (IX+1)
 ex de,hl
 ld (hl),a
 inc hl
 inc de
 inc IX
 inc IX
 push bc
  ld b,$0
  add hl,bc
 pop bc
 djnz drawloop
 ret
 
CenterSprite:
 
 ld de,(spritetype)
 ld L,a
 ld h,$0
 add hl,hl ;*2
 add hl,hl ;*4
 add hl,hl ;*8
 add hl,hl ;*16
 add hl,hl ;*32, to jump over the second tile
 add hl,de  ;adds offset.
 push hl
 pop IX     ;now has the address of the sprite in IX.
 ld hl,$0008
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,de  ;DE has already been set, and it hasn't been altered since.
 ex de,hl
 call CenterSpriteRoutine
 ret
 
;============================================================================
AD:
;Tile detailing routine:
;ARG: HL = Address row to change
;Notes: Destroys all registers
;
;============================================================================
;LSB right/left/down/up, set if water is present

 ld b,$00       ;256 count
 ld a,$20
 out ($10),a    ;resets the LCD display.
 ld d,$10	;quick register comparing in the loop
 ld c,$1        ;ditto.

ADloop:
 ld a,(hl)
 or a
 jr nz,ADEnder
 ld e,$0          ;resets E so that it can be tested again.
 call IncreaseHL  ;looking right
 ld a,(hl)
 cp d             ;prevents testing of details as non-detailing.
 jr nc,Zerotest01
 cp c
 ccf
Zerotest01:
 ccf
 rl e              ;if carry, then bit is shifted into place.
 call DecreaseHL
 call DecreaseHL
 ld a,(hl)
 cp d             ;prevents testing of details as non-detailing.
 jr nc,Zerotest02
 cp c
 ccf
Zerotest02:
 ccf
 rl e              ;if carry, then bit for LEFT is shifted.
 call IncreaseHL
 call IncreaseH   ;looking down, now.
 ld a,(hl)
 cp d             ;prevents testing of details as non-detailing.
 jr nc,Zerotest03
 cp c
 ccf
Zerotest03:
 ccf
 rl e
 call DecreaseH
 call DecreaseH
 ld a,(hl)
 cp d             ;prevents testing of details as non-detailing.
 jr nc,Zerotest04
 cp c
 ccf
Zerotest04:
 ccf
 rl e
 call IncreaseH   ;normalizes HL.
 ld a,e
 out ($11),a       ;display what's going on here! (for debugging...)
 cp %00001001
 jr nz,AD_Nx01
 ld (hl),$11
 jr ADEnder
AD_Nx01:
 cp %00001010
 jr nz,AD_Nx02
 ld (hl),$10
 jr ADEnder
AD_Nx02:
 cp %00000110
 jr nz,AD_Nx03
 ld (hl),$13
 jr ADEnder
AD_Nx03:
 cp %00000101
 jr nz,ADEnder
 ld (hl),$12

ADEnder:
 call IncreaseHL
 djnz ADloop
 ret
 
CoordToMapPos:
 ld hl,(xpos)
 ld a,h
 and %11000000
 rlca
 rlca
 add a,2
 out (5),a
 ld a,h
 or %11000000
 ld h,a
 ret

spriteRefresh:
 push hl
  push de
   push af
   in a,(5)
   push af
    call redrawAirship
    call redrawBoat
    ld hl,(spritetype)
    push hl
     ld de,ASST
     or a
     sbc hl,de
     push af
      call z,redrawBoat
     pop af
     call z,removeAirship
    pop hl
    push hl
     ld de,BTST
     or a
     sbc hl,de
     push af
      call z,redrawAirship
     pop af
     call z,removeBoat
    pop hl
   pop af
   out (5),a
  pop de
 pop hl
 ret

removeBoat:
 ld hl,(boatpos)
 ld de,(xpos)
 ld (xpos),hl
 call CoordToMapPos
 ld (xpos),de
 ld (hl),$00
 ld hl,$FFFF
 ld (boatpos),hl
 ret
redrawBoat:
 ld hl,(xpos)
 ld (boatpos),hl
 call CoordToMapPos
 ld (hl),$18
 ret
removeAirship:
 ld hl,(airshippos)
 ld de,(xpos)
 ld (xpos),hl
 call CoordToMapPos
 ld (xpos),de
 ld a,(templandsprite)
 ld (hl),a
 ld hl,$FFFF
 ld (airshippos),hl
 ret
redrawAirship:
 ld hl,(xpos)
 ld (airshippos),hl
 call CoordToMapPos
 ld (hl),$15
 ret
 
directGetKey:
 push hl
 call directGetKeySub
 pop hl
 ret
directGetKeySub:
 bcall(_getCSC)
 ld hl,endDirectGetKey
 push hl
 ld h,$EF \ cp $35 \ ret z
 ld h,$DF \ cp $36 \ ret z
 ld h,$BF \ cp $37 \ ret z
 ld h,$7F \ cp $38 \ ret z
 ld h,$F7 \ cp $04 \ ret z
 ld h,$FB \ cp $03 \ ret z
 ld h,$FD \ cp $02 \ ret z
 ld h,$FE \ cp $01 \ ret z
 ld h,$FF
endDirectGetKey:
 ld a,h
 ret

 
displayingCharacterSprite:
  ld hl,spriteshift
  inc (hl)
  bit 0,(hl)        ;every 2 executions, this routine will shift the sprite around.  
  ld c,24
  ld a,9
  call z,CenterSprite
  ld a,(spriteshift)
  bit 2,a  
  ld a,(spriteposition)
  ld b,a
  jr z,TMSS_NoFix
  and %00000001
  ld a,b
  jp z,TMSS_IncFix
  dec a
  jr TMSS_NoFix
TMSS_IncFix:
  inc a 
TMSS_NoFix:

  ld bc,(spriteheight)
  call CenterSprite
  ret

 
 
 
 
 
 
 
 
 

ASCIIcounter1:
.db 0,0,0,0,0,"  X  "
ASCIIcounter2:
.db 0,0,0,0,0,"  Y  ",0


ArtificalStack:
.ds 400
ArtificialStackEnd:

;======================================\\
;=======================================\\
;#include "tmapDat1.asm"                ;|| Data for the specified detailing routine.
;=======================================//
;======================================//

;======================================\\
;=======================================\\
#include "tmapDat2.asm"                ;|| Tilebitmap data
;=======================================//
;======================================//


;======================================================================================================
;******************************************************************************************************
;--------------------- String data, to give tester the idea of what's going on. -----------------------
;--------------------- But most of the time, it goes too fast for the human eye -----------------------
;******************************************************************************************************
;======================================================================================================

str0: .db "Begin Program   ",0
str1: .db "Detecting AppVar",0
str2: .db "AdrDataBufferR/W",0
str3: .db "Press enter.    ",0
fail: .db "Program failure."
      .db "Must terminate  "
      .db "immediately.    ",0
tm1:  .db "Map Walk mode   ",0
tm2:  .db "Map Boat mode   ",0
tm3:  .db "Map Airship mode",0

program:
.db ProtProgObj,"TMAP3",0,0,0,0,0
savefile:
.db AppVarObj,"FnFntsyS"

.end

preservedtiles:    ;its here so that it won't affect the code if I compile before readjusting the map.








